@@ -1,4 +1,4 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
 # Copyright 2015 Calculate Ltd. http://www.calculate-linux.org
 #
@@ -13,8 +13,8 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
+
 from itertools import chain
-import random
 import re
 import sys
 import time
@@ -45,10 +45,9 @@ import os
 from os import path
 from .datavars import BuilderError
 from .emerge_fetch import EmergeFetcher, EmergeFetcherError
-from calculate.install.distr import SquashDistributive
-from calculate.builder.variables.action import Actions
 
-from calculate.lib.cl_lang import (setLocalTranslate, getLazyLocalTranslate, _)
+_ = lambda x: x
+from calculate.lib.cl_lang import (setLocalTranslate, getLazyLocalTranslate)
 setLocalTranslate('cl_builder3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
 
@@ -720,7 +719,7 @@ class Builder(Update):
                         mult=mult, package=pkg['CATEGORY/PN']))
         return True
 
-    def emergelike(self, builder_path, cmd, *params):
+    def chroot_emergelike(self, builder_path, cmd, *params):
         """
         Запуск команды, которая подразумевает выполнение emerge
         """
@@ -734,7 +733,7 @@ class Builder(Update):
             self._startEmerging(emerge)
         return True
 
-    def revdep_rebuild(self, builder_path, cmd, *params):
+    def chroot_revdep_rebuild(self, builder_path, cmd, *params):
         """
         Запуск revdep-rebulid
         """
