@@ -15,7 +15,7 @@
 #  limitations under the License.
 
 import sys
-from calculate.core.server.func import Action, Tasks
+from calculate.core.server.func import Action
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 from calculate.lib.cl_template import TemplatesError
 from calculate.lib.utils.files import FilesError
@@ -23,9 +23,10 @@ from calculate.update.emerge_parser import EmergeError
 from calculate.update.update import UpdateError
 from ..datavars import BuilderError
 from calculate.lib.utils.portage import GitError
-from calculate.install.distr import DistributiveError, IsoDistributive
+from calculate.install.distr import DistributiveError
 from calculate.builder.variables.action import Actions
 
+_ = lambda x: x
 setLocalTranslate('cl_builder3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
 
@@ -39,7 +40,7 @@ class ClBuilderMenuAction(Action):
                     TemplatesError,
                     BuilderError, GitError, EmergeError)
 
-    successMessage =__("Boot menu updated successfully")
+    successMessage = __("Boot menu updated successfully")
     failedMessage = __("Failed to update boot menu")
     interruptMessage = __("Boot menu updating manually interrupted")
 
@@ -47,7 +48,7 @@ class ClBuilderMenuAction(Action):
     tasks = [
         {'name': 'mount_flash',
          'method': 'Builder.remount_rw(cl_builder_flash_path)',
-        },
+         },
         {'name': 'iso_linux_migrate',
          'method': 'Builder.iso_migrate(cl_builder_flash_path)'
          },
