@@ -18,12 +18,13 @@ import sys
 from calculate.core.server.func import Action, Tasks
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 from calculate.lib.cl_template import TemplatesError
-from calculate.lib.utils.files import FilesError, isMount
+from calculate.lib.utils.files import FilesError
 from calculate.update.update import UpdateError
 from ..datavars import BuilderError
-from calculate.lib.utils.portage import GitError, isPkgInstalled
+from calculate.lib.utils.portage import GitError
 from calculate.install.distr import DistributiveError
 
+_ = lambda x: x
 setLocalTranslate('cl_builder3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
 
@@ -56,7 +57,7 @@ class ClBuilderProfileAction(Action):
              Get('cl_builder_profile_storage').is_local(
                  Get('cl_builder_profile_url'),
                  Get('cl_builder_profile_branch')))
-        },
+         },
         {'name': 'reconfigure_vars1',
          'method': 'Builder.invalidateVariables("cl_builder_profile_storage")',
          'depend': Tasks.has('migrate_repository')
@@ -80,16 +81,16 @@ class ClBuilderProfileAction(Action):
               'foreach': 'cl_builder_profile_sync_rep',
               'message': __("Syncing the {eachvar:capitalize} repository"),
               'method': 'Builder.syncRepositories(eachvar)',
-             },
+              },
              {'name': 'regen_cache',
               'foreach': 'cl_builder_sync_overlay_rep',
               'essential': False,
               'method': 'Builder.regenCache(eachvar)',
-             },
+              },
              {'name': 'eix_update',
               'message': __("Updating the eix cache"),
               'method': 'Builder.eixUpdate(cl_builder_repository_name)',
-             },
+              },
              # save
              {'name': 'save',
               'method': 'Builder.save_build(cl_builder_build,'
@@ -102,7 +103,7 @@ class ClBuilderProfileAction(Action):
                                                          "sync_other_reps",
                                                          "emerge_metadata",
                                                          "eix_update")),
-             }
+              }
          ]
          },
         {'name': 'reps_synchronization',
@@ -114,9 +115,10 @@ class ClBuilderProfileAction(Action):
               'method': 'Builder.set_profile('
                         'cl_builder_profile_system_shortname,cl_builder_path)'
               },
-             #{'name': 'merge_utils',
+             # {'name': 'merge_utils',
              # 'message': __("Calculating dependencies"),
-             # 'method': 'Builder.emerge("-console -pxe","-1","sys-apps/calculate-utils")',
+             # 'method': 'Builder.emerge("-console -pxe","-1",'
+             #           '"sys-apps/calculate-utils")',
              # # TODO: возможно добавить параметр необходимости установки
              # 'condition': lambda Get: not isPkgInstalled(
              #     'sys-apps/calculate-utils', Get('cl_builder_path'))
@@ -130,19 +132,19 @@ class ClBuilderProfileAction(Action):
                   Get('update.cl_update_skip_setup_set') == 'off')
               },
              {'name': 'fix_settings',
-               'message': __("Fixing the settings"),
-               'method': 'Builder.apply_templates(cl_builder_path,'
-                         'cl_template_clt_set,True,None,False,"sync",'
-                         'cl_builder_profile_datavars)',
-               'condition': lambda Get: Get('cl_templates_locate')
+              'message': __("Fixing the settings"),
+              'method': 'Builder.apply_templates(cl_builder_path,'
+                        'cl_template_clt_set,True,None,False,"sync",'
+                        'cl_builder_profile_datavars)',
+              'condition': lambda Get: Get('cl_templates_locate')
               },
-              {'name': 'dispatch_conf',
-               'message': __("Updating configuration files"),
-               'method':'Builder.dispatchConf(None,cl_builder_path)',
-               'condition': lambda Get: Get('cl_dispatch_conf') != 'skip'
+             {'name': 'dispatch_conf',
+              'message': __("Updating configuration files"),
+              'method': 'Builder.dispatchConf(None,cl_builder_path)',
+              'condition': lambda Get: Get('cl_dispatch_conf') != 'skip'
               },
          ]
-        },
+         },
         {'name': 'failed',
          'error': __("Failed to update the profile"),
          'depend': (Tasks.failed() & Tasks.hasnot("interrupt") &
