@@ -18,19 +18,37 @@ import sys
 from calculate.core.server.func import Action, Tasks
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 from calculate.lib.cl_template import TemplatesError
-from calculate.lib.utils.files import FilesError, isMount
+from calculate.lib.utils.files import FilesError
 from calculate.update.emerge_parser import EmergeError
 from calculate.update.update import UpdateError
 from ..datavars import BuilderError
-from calculate.lib.utils.portage import GitError, isPkgInstalled, \
-    EmergeLogNamedTask, PackageList, EmergeLog
+from calculate.lib.utils.portage import (GitError, EmergeLogNamedTask,
+                                         PackageList, EmergeLog)
 from calculate.install.distr import DistributiveError
-from os import path
 from calculate.update.update_tasks import EmergeMark
 
+_ = lambda x: x
 setLocalTranslate('cl_builder3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
 
+class BuilderConditions(object):
+    @staticmethod
+    def was_installed(pkg, task_name):
+        def func(Get):
+            task = EmergeLog(EmergeLogNamedTask(task_name),
+                             prefix=Get('cl_builder_path'))
+            return bool(PackageList(task.list)[pkg])
+
+        return func
+
+    @staticmethod
+    def need_depclean(pkg, task_name):
+        def func(Get):
+            task = EmergeLog(EmergeLogNamedTask(task_name),
+                             prefix=Get('cl_builder_path'))
+            return bool(PackageList(task.list)[pkg])
+
+        return func
 
 class ClBuilderUpdateAction(Action):
     """
@@ -45,22 +63,6 @@ class ClBuilderUpdateAction(Action):
     failedMessage = None
     interruptMessage = __("System update manually interrupted")
 
-    def was_installed(pkg, task_name):
-        def func(Get):
-            task = EmergeLog(EmergeLogNamedTask(task_name),
-                             prefix=Get('cl_builder_path'))
-            return bool(PackageList(task.list)[pkg])
-
-        return func
-
-    def need_depclean(pkg, task_name):
-        def func(Get):
-            task = EmergeLog(EmergeLogNamedTask(task_name),
-                             prefix=Get('cl_builder_path'))
-            return bool(PackageList(task.list)[pkg])
-
-        return func
-
     # список задач для действия
     tasks = [
         {'name': 'check_build_run',
@@ -80,7 +82,7 @@ class ClBuilderUpdateAction(Action):
         {'name': 'reconfigure_vars',
          'method': 'Builder.reconfigureProfileVars(cl_builder_linux_datavars,'
                    'cl_builder_path)'
-        },
+         },
         {'name': 'apply_branch_vars',
          'method': 'Builder.apply_branch_variables()'
          },
@@ -92,12 +94,13 @@ class ClBuilderUpdateAction(Action):
              {'name': 'sync_reps_fallback',
               'foreach': 'cl_builder_sync_rep',
               'message':
-                  __("Fallback syncing the {eachvar:capitalize} repository"),
+                  __(
+                      "Fallback syncing the {eachvar:capitalize} repository"),
               'method': 'Builder.syncRepositories(eachvar)',
               'condition': lambda Get: (
                   Get('cl_builder_binary_set') == "on" and
                   not Get('update.cl_update_binhost_data')[0])
-             },
+              },
              # обновление переменных информации из binhost
              {'name': 'invalidate_vars',
               'method':
@@ -108,25 +111,29 @@ class ClBuilderUpdateAction(Action):
               },
              {'name': 'binhost_unavailable',
               'error': __("Update server is unavailable"),
-              'condition': lambda Get:(
+              'condition': lambda Get: (
                   Get('cl_builder_binary_set') == "on" and
                   not Get('update.cl_update_binhost_data')[0])
               },
              {'name': 'sync_reps',
               'foreach': 'cl_builder_sync_rep',
-              'message': __("Syncing the {eachvar:capitalize} repository"),
+              'message': __(
+                  "Syncing the {eachvar:capitalize} repository"),
               'method': 'Builder.syncRepositories(eachvar)',
               'condition': lambda Get: Get('cl_builder_sync_rep')
-             },
+              },
              {'name': 'check_binhost',
               'method': 'Builder.check_binhost(True)',
-              'condition': lambda Get: Get('cl_builder_binary_set') == "on"
+              'condition': lambda Get: Get(
+                  'cl_builder_binary_set') == "on"
               },
              {'name': 'sync_other_reps',
               'foreach': 'builder.cl_builder_other_rep_name',
-              'message': __("Syncing the {eachvar:capitalize} repository"),
+              'message': __(
+                  "Syncing the {eachvar:capitalize} repository"),
               'method': 'Builder.syncLaymanRepository(eachvar)',
-              'condition': lambda Get: Get('update.cl_update_other_set') == 'on'
+              'condition': lambda Get: Get(
+                  'update.cl_update_other_set') == 'on'
               },
              {'name': 'regen_cache',
               'foreach': 'cl_builder_sync_overlay_rep',
@@ -136,7 +143,7 @@ class ClBuilderUpdateAction(Action):
                   Get('builder.cl_builder_outdate_set') == 'on' and
                   Get('update.cl_update_egencache_force') != 'skip' or
                   Get('update.cl_update_egencache_force') == 'force'))
-             },
+              },
              {'name': 'eix_update',
               'message': __("Updating the eix cache"),
               'method': 'Builder.eixUpdate(cl_builder_repository_name)',
@@ -144,9 +151,10 @@ class ClBuilderUpdateAction(Action):
                   Get('builder.cl_builder_outdate_set') == 'on' and
                   Get('update.cl_update_eixupdate_force') != 'skip' or
                   Get('update.cl_update_eixupdate_force') == 'force'))
-             },
+              },
              {'name': 'sync_reps:cleanpkg',
-              'message': __("Removing obsolete distfiles and binary packages"),
+              'message': __(
+                  "Removing obsolete distfiles and binary packages"),
               'method': 'Builder.cleanpkg()',
               'condition': lambda Get: (
                   Get('builder.cl_builder_outdate_set') == 'on' and
@@ -160,9 +168,9 @@ class ClBuilderUpdateAction(Action):
                                                          "sync_other_reps",
                                                          "emerge_metadata",
                                                          "eix_update")),
-             }
+              }
          ]
-        },
+         },
         {'name': 'reps_synchronization',
          'group': __("System configuration"),
          'tasks': [
@@ -172,14 +180,14 @@ class ClBuilderUpdateAction(Action):
                         'cl_template_clt_set,True,None,False,"sync",'
                         'cl_builder_linux_datavars)',
               'condition': lambda Get: Get('cl_templates_locate')
-             },
+              },
              {'name': 'dispatch_conf',
               'message': __("Updating configuration files"),
               'method': 'Builder.dispatchConf(None,cl_builder_path)',
               'condition': lambda Get: Get('cl_dispatch_conf') != 'skip'
-             },
-        ]
-        },
+              },
+         ]
+         },
         {'name': 'emerge_update_world',
          'group': __("Updating packages"),
          'tasks': [
@@ -206,19 +214,20 @@ class ClBuilderUpdateAction(Action):
               'method': 'Builder.rebuild_changed_packages(cl_builder_path,'
                         'cl_builder_repository_data)',
               'condition': lambda Get:
-                  Get('cl_builder_rebuild_changed_set') == 'on'
+              Get('cl_builder_rebuild_changed_set') == 'on'
               }
          ]
-        },
+         },
         {'name': 'update_other:update_python',
          'group': __("Updating Python"),
          'tasks': [
              {'name': 'python_updater',
               'message': __('Find & rebuild packages broken due '
                             'to a Python upgrade'),
-              'method': 'Builder.emergelike(cl_builder_path,"python-updater")',
-              'condition': was_installed('dev-lang/python$',
-                                         EmergeMark.PythonUpdater),
+              'method': 'Builder.chroot_emergelike(cl_builder_path,'
+                        '"python-updater")',
+              'condition': BuilderConditions.was_installed(
+                  'dev-lang/python$', EmergeMark.PythonUpdater),
               'decoration': 'Builder.update_task("%s")' %
                             EmergeMark.PythonUpdater
               },
@@ -228,12 +237,13 @@ class ClBuilderUpdateAction(Action):
          'group': __("Updating Perl"),
          'tasks': [
              {'name': 'perl_cleaner',
-              'message': __('Find & rebuild packages and Perl header files '
-                            'broken due to a perl upgrade'),
-              'method': 'Builder.emergelike(cl_builder_path,"perl-cleaner",'
-                        '"all")',
-              'condition': was_installed('dev-lang/perl$',
-                                         EmergeMark.PerlCleaner),
+              'message': __(
+                  'Find & rebuild packages and Perl header files '
+                  'broken due to a perl upgrade'),
+              'method': 'Builder.chroot_emergelike(cl_builder_path,'
+                        '"perl-cleaner","all")',
+              'condition': BuilderConditions.was_installed(
+                  'dev-lang/perl$', EmergeMark.PerlCleaner),
               'decoration': 'Builder.update_task("%s")' % EmergeMark.PerlCleaner
               },
          ]
@@ -246,15 +256,15 @@ class ClBuilderUpdateAction(Action):
               'method': 'Builder.depclean()',
               },
          ]
-        },
+         },
         {'name': 'update_world:update_modules',
          'group': __("Rebuilding dependent modules"),
          'tasks': [
              {'name': 'update_world:module_rebuild',
               'message': __('Updating Kernel modules'),
               'method': 'Builder.emerge(cl_builder_path,"","@module-rebuild")',
-              'condition': was_installed('sys-kernel/.*source',
-                                         EmergeMark.KernelModules),
+              'condition': BuilderConditions.was_installed(
+                  'sys-kernel/.*source', EmergeMark.KernelModules),
               'decoration': 'Builder.update_task("%s")' %
                             EmergeMark.KernelModules
               },
@@ -262,25 +272,26 @@ class ClBuilderUpdateAction(Action):
               'message': __('Updating X.Org server modules'),
               'method': 'Builder.emerge(cl_builder_path,"",'
                         '"@x11-module-rebuild")',
-              'condition': was_installed('x11-base/xorg-server',
-                                         EmergeMark.XorgModules),
+              'condition': BuilderConditions.was_installed(
+                  'x11-base/xorg-server', EmergeMark.XorgModules),
               'decoration': 'Builder.update_task("%s")' % EmergeMark.XorgModules
               },
              {'name': 'update_world:preserved_rebuild',
               'message': __('Updating preserved libraries'),
               'method': 'Builder.emerge(cl_builder_path,"",'
                         '"@preserved-rebuild")',
-              'condition': was_installed('.*', EmergeMark.PreservedLibs),
+              'condition': BuilderConditions.was_installed(
+                  '.*', EmergeMark.PreservedLibs),
               'decoration': 'Builder.update_task("%s")' %
                             EmergeMark.PreservedLibs
               },
              {'name': 'update_world:revdev_rebuild',
               'message': __('Checking reverse dependencies'),
-              'method': 'Builder.revdep_rebuild(cl_builder_path,'
+              'method': 'Builder.chroot_revdep_rebuild(cl_builder_path,'
                         '"revdep-rebuild")',
               'condition': lambda Get: (
                   Get('update.cl_update_skip_rb_set') == 'off' and
-                  ClBuilderUpdateAction.was_installed(
+                  BuilderConditions.was_installed(
                       '.*', EmergeMark.RevdepRebuild)(Get)),
               'decoration': 'Builder.update_task("%s")' %
                             EmergeMark.RevdepRebuild
@@ -293,27 +304,27 @@ class ClBuilderUpdateAction(Action):
              {'name': 'update_world:binary_cleaning',
               'message': __("Cleaning the binary repository"),
               'method': 'Builder.binaryCleaning()',
-              'condition': lambda Get: Get('cl_builder_binary_set') == "off"
+              'condition': lambda Get: Get(
+                  'cl_builder_binary_set') == "off"
               },
-        ],
+         ],
          'depend': Tasks.has("update_other")
-        },
+         },
         {'name': 'update_other:reading_news',
          'method': 'Builder.reading_news(cl_builder_path)',
          'essential': False
-        },
+         },
         {'name': 'update_other:check_obsolete',
          'method': 'Builder.check_obsolete(cl_builder_path)'
-        }
+         }
     ] + [
         {'name': 'failed',
          'error': __("Failed to update the system"),
          'depend': (Tasks.failed() & Tasks.hasnot("interrupt") &
                     Tasks.success_all("check_build_run"))
-        },
+         },
         # сообщение удачного завершения при обновлении ревизии
         {'name': 'update_other:success_rev',
-         'message':  __("The system was successfully updated"),
+         'message': __("The system was successfully updated"),
          }
     ]
-    was_installed = staticmethod(was_installed)
