@@ -23,7 +23,7 @@ from calculate.install.distr import DistributiveError, IsoDistributive
 from calculate.install.variables.kernel import KernelConfig
 from calculate.lib.utils.dracut import Dracut
 from calculate.lib.utils.portage import getSquashList
-from calculate.lib.variables.system import VariableOsRootType, RootType
+from calculate.lib.variables.system import RootType
 from .action import Actions
 from calculate.install import distr
 from calculate.lib.utils.device import getUdevDeviceInfo, humanreadableSize
@@ -69,14 +69,6 @@ def is_action(*available_action, **action_kwargs):
     return decorator
 
 
-def as_list(func):
-    @wraps(func)
-    def _wrapped_func(self, *args, **kw):
-        return list(func(self, *args, **kw))
-
-    return _wrapped_func
-
-
 class VariableClBuilderStorage(ReadonlyVariable):
     type = "object"
 
@@ -562,23 +554,21 @@ class VariableClBuilderPreparedId(BaseBuildId):
     type = "choice"
     untrusted = True
 
-    @as_list
     def available(self):
         bs = self.Get('cl_builder_storage')
         action = self.Get('cl_action')
         for x in bs:
             build = bs.get_build(x)
             if (build and (action == Actions.Break or
-                                   build.status == Build.Status.Worked)):
+                           build.status == Build.Status.Worked)):
                 yield x
 
     def get(self):
-        l = self.available()
+        l = list(self.available())
         if l and len(l) == 1:
             return l[0]
         return ""
 
-    @as_list
     def choice(self):
         bs = self.Get('cl_builder_storage')
         for x in bs:
@@ -592,7 +582,7 @@ class VariableClBuilderPreparedId(BaseBuildId):
     def check(self, value):
         if not value:
             raise VariableError(_("Please select the build ID"))
-        l = self.available()
+        l = list(self.available())
         if not l:
             raise VariableError(_("Build %s is not found") % value)
         if (self.Get('cl_builder_build').status == Build.Status.Broken and
@@ -608,7 +598,6 @@ class VariableClBuilderBrokenId(BaseBuildId):
     type = "choice"
     untrusted = True
 
-    @as_list
     def available(self):
         bs = self.Get('cl_builder_storage')
         for x in bs:
@@ -618,12 +607,11 @@ class VariableClBuilderBrokenId(BaseBuildId):
 
     @is_action(Actions.Restore)
     def get(self):
-        l = self.available()
+        l = list(self.available())
         if l and len(l) == 1:
             return l[0]
         return ""
 
-    @as_list
     @is_action(Actions.Restore, default_value=[])
     def choice(self):
         bs = self.Get('cl_builder_storage')
@@ -635,7 +623,7 @@ class VariableClBuilderBrokenId(BaseBuildId):
     def check(self, value):
         if not value:
             raise VariableError(_("Please select the build ID"))
-        l = self.available()
+        l = list(self.available())
         if not l:
             raise VariableError(_("Build %s is not found") % value)
 
@@ -778,6 +766,7 @@ class VariableClBuilderImageFilename(Variable):
             else:
                 isoname = "%s-%s-%s.iso" % (shortname, buildnumber,
                                             arch)
+            fullname = ""
             for i_dn in filter(None, (dn, addon_dn)):
                 fullname = path.join(i_dn, isoname)
                 if not rewrite and path.exists(fullname):
