@@ -15,17 +15,13 @@
 #  limitations under the License.
 
 import sys
-import os
-from os import path
 import re
 from calculate.install import distr
 from calculate.install.distr import DistributiveError
-from calculate.lib.datavars import ReadonlyVariable, SimpleDataVars, \
-    VariableError, ReadonlyTableVariable, FieldValue
+from calculate.lib.datavars import (ReadonlyVariable, VariableError,
+                                    ReadonlyTableVariable, FieldValue)
 from calculate.lib.utils.files import pathJoin
-from calculate.lib.utils.portage import Layman
 from calculate.lib.utils.tools import ignore
-from calculate.lib.variables import linux
 from calculate.lib.variables import env
 from calculate.update.variables import update
 from calculate.lib.variables import system, linux
@@ -33,8 +29,8 @@ from .action import Actions
 
 from calculate.lib.cl_lang import setLocalTranslate
 import datetime
-import profiles
 
+_ = lambda x: x
 setLocalTranslate('cl_builder3', sys.modules[__name__])
 
 
@@ -225,17 +221,6 @@ class VariableOsBuilderLinuxName(BuilderLinux):
 class VariableClBuilderProfileSystem(BuilderLinux):
     variable = "cl_profile_system"
 
-    #def get(self):
-    #    action = self.Get('cl_action')
-    #    if action == 'create':
-    #        shortname = self.Get('cl_builder_profile_system_shortname')
-    #        profile = self.Select('cl_builder_profile_path',
-    #                              where="cl_builder_profile_shortname",
-    #                              eq=shortname, limit=1)
-    #        if profile:
-    #            return profile
-    #    return ""
-
 
 class VariableOsBuilderLinuxSystem(BuilderLinux):
     """
@@ -286,7 +271,7 @@ class VariableClBuilderPortdirOverlay(ReadonlyVariable):
     def get(self):
         return [location
                 for name, location in
-                    filter(None,self.Get('builder.cl_builder_repository_data'))
+                filter(None, self.Get('builder.cl_builder_repository_data'))
                 if name not in ("portage", "gentoo")]
 
 class VariableClBuilderOtherRepData(update.VariableClUpdateOtherRepData):
@@ -320,7 +305,7 @@ class VariableClBuilderRepositoryData(ReadonlyTableVariable):
     """
     source = ["cl_repository_name", "cl_repository_location"]
 
-    def get(self):
+    def get(self, hr=False):
         try:
             dv = self.Get('cl_builder_linux_datavars')
             if dv:
