@@ -15,15 +15,10 @@
 #  limitations under the License.
 
 import sys
-import os
 from os import path
-from calculate.lib.datavars import (ReadonlyVariable, FieldValue, VariableError,
-                                    DataVarsError, Variable)
-from calculate.lib.utils.files import listDirectory
-from calculate.lib.utils.portage import GitError
+from calculate.lib.datavars import (ReadonlyVariable, FieldValue)
 from calculate.lib.variables import linux as lib_linux
 from calculate.lib.variables import system as lib_system
-from calculate.install import distr
 from calculate.update.variables import update
 from calculate.update import profile as update_profile
 
@@ -31,6 +26,7 @@ from calculate.update import profile as update_profile
 from calculate.lib.cl_lang import setLocalTranslate
 from calculate.update.variables.update import DataVarsUpdateProfile
 
+_ = lambda x: x
 setLocalTranslate('cl_builder3', sys.modules[__name__])
 
 class VariableClBuilderProfileStorage(ReadonlyVariable):
