@@ -1,4 +1,4 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
 # Copyright 2015 Calculate Ltd. http://www.calculate-linux.org
 #
@@ -33,10 +33,13 @@ from utils.cl_builder_update import ClBuilderUpdateAction
 from utils.cl_builder_restore import ClBuilderRestoreAction
 from utils.cl_builder_image import ClBuilderImageAction
 from utils.cl_builder_menu import ClBuilderMenuAction
-from calculate.lib.cl_lang import setLocalTranslate,getLazyLocalTranslate
-setLocalTranslate('cl_builder3',sys.modules[__name__])
+_ = lambda x: x
+from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
+
+setLocalTranslate('cl_builder3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
 
+
 class Wsdl(WsdlBase):
     methods = [
         #
@@ -72,34 +75,35 @@ class Wsdl(WsdlBase):
             # описание груп (список лямбда функций)
             'groups': [
                 # Подготовить новую сборку
-                lambda group: group(_("Prepare the New Build"),
-                                # Исходный образ (Source image)
-                                normal=('cl_builder_source_filename',),
-                                # Идентификатор сборки (Build ID)
-                                expert=(# Место сборки
-                                        # (Build location)
-                                        'cl_builder_disk_dev',
-                                        # Использовать слои для сборки
-                                        # Use layers for build
-                                        'cl_builder_layered_set',
-                                        'cl_builder_new_id',
-                                        'cl_templates_locate',
-                                        'cl_verbose_set',
-                                        'cl_dispatch_conf'),
-                                hide=('cl_templates_locate',
-                                      'cl_verbose_set',
-                                      'cl_builder_disk_dev',
-                                      'cl_builder_layered_set',
-                                      'cl_builder_new_id',
-                                      'cl_dispatch_conf'),
-                                brief=('cl_builder_source_filename',
-                                       'cl_builder_profile_name',
-                                       'cl_builder_disk_dev',
-                                       'cl_builder_new_id',
-                                       'cl_builder_layered_set',
-                                       'cl_builder_disk_size',
-                                ),
-                                next_label=_("Next"))],
+                lambda group: group(
+                    _("Prepare the New Build"),
+                    # Исходный образ (Source image)
+                    normal=('cl_builder_source_filename',),
+                    # Идентификатор сборки (Build ID)
+                    expert=(  # Место сборки
+                              # (Build location)
+                              'cl_builder_disk_dev',
+                              # Использовать слои для сборки
+                              # Use layers for build
+                              'cl_builder_layered_set',
+                              'cl_builder_new_id',
+                              'cl_templates_locate',
+                              'cl_verbose_set',
+                              'cl_dispatch_conf'),
+                    hide=('cl_templates_locate',
+                          'cl_verbose_set',
+                          'cl_builder_disk_dev',
+                          'cl_builder_layered_set',
+                          'cl_builder_new_id',
+                          'cl_dispatch_conf'),
+                    brief=('cl_builder_source_filename',
+                           'cl_builder_profile_name',
+                           'cl_builder_disk_dev',
+                           'cl_builder_new_id',
+                           'cl_builder_layered_set',
+                           'cl_builder_disk_size',
+                           ),
+                    next_label=_("Next"))],
             'brief': {'next': __("Perform"),
                       'name': __("Prepare the New Build")},
         },
@@ -260,7 +264,8 @@ class Wsdl(WsdlBase):
                 lambda group: group(_("Break the Build"),
                                     normal=('cl_builder_broken_id',),
                                     expert=('cl_templates_locate',
-                                            'cl_verbose_set', 'cl_dispatch_conf'),
+                                            'cl_verbose_set',
+                                            'cl_dispatch_conf'),
                                     next_label=_("Perform"))],
         },
         {
@@ -337,7 +342,7 @@ class Wsdl(WsdlBase):
                                         'cl_templates_locate',
                                         'cl_verbose_set',
                                         'cl_dispatch_conf'),
-                                    next_label=_("Next")),],
+                                    next_label=_("Next"))],
             'brief': {'next': __("Perform"),
                       'name': __("Create the Image")}
         },
@@ -373,26 +378,28 @@ class Wsdl(WsdlBase):
                         'update.cl_update_world_default': 'rebuild'},
             # описание груп (список лямбда функций)
             'groups': [
-                lambda group: group(_("Repository"),
-                                brief=('cl_builder_profile_repo_name',),
-                                hide=('cl_builder_profile_url',
-                                      'update.cl_update_profile_sync_set'),
-                                normal=('cl_builder_prepared_id',
-                                        'cl_builder_profile_url',),
-                                expert=('update.cl_update_profile_sync_set',)),
-                lambda group: group(_("Profile"),
-                                normal=('cl_builder_profile_system_shortname',
-                                        'update.cl_update_world'),
-                                expert=('update.cl_update_skip_setup_set',
-                                        'cl_builder_templates_locate',
-                                        'cl_verbose_set',
-                                        'cl_dispatch_conf'),
-                                hide=('cl_builder_templates_locate',
-                                      'cl_verbose_set',
-                                      'cl_dispatch_conf'),
-                                brief=('cl_builder_profile_linux_fullname',
-                                       'cl_builder_profile_depend_data')
-                                )],
+                lambda group: group(
+                    _("Repository"),
+                    brief=('cl_builder_profile_repo_name',),
+                    hide=('cl_builder_profile_url',
+                          'update.cl_update_profile_sync_set'),
+                    normal=('cl_builder_prepared_id',
+                            'cl_builder_profile_url',),
+                    expert=('update.cl_update_profile_sync_set',)),
+                lambda group: group(
+                    _("Profile"),
+                    normal=('cl_builder_profile_system_shortname',
+                            'update.cl_update_world'),
+                    expert=('update.cl_update_skip_setup_set',
+                            'cl_builder_templates_locate',
+                            'cl_verbose_set',
+                            'cl_dispatch_conf'),
+                    hide=('cl_builder_templates_locate',
+                          'cl_verbose_set',
+                          'cl_dispatch_conf'),
+                    brief=('cl_builder_profile_linux_fullname',
+                           'cl_builder_profile_depend_data')
+                )],
             'brief': {'next': __("Perform"),
                       'name': __("Set the Profile")}},
     ]
